#
# Firefox Brower Emulator
#


{ pkgs, ... }:

{

  home.packages = [ pkgs.firefox-wayland ];

  programs = {
    firefox = {
      enable = true;
      package = pkgs.wrapFirefox pkgs.firefox-unwrapped {
          forceWayland = true;
          extraPolicies = {
              ExtensionSettings =  {};
          };
      };
      profiles.kabbone = {
          id = 271987;
          name = "kabtop";
          isDefault = true;
          search = {
            engines = {
              "Nix Packages" = {
                  urls = [{
                    template = "https://search.nixos.org/packages";
                    params = [
                      { name = "type"; value = "packages"; }
                      { name = "query"; value = "{searchTerms}"; }
                    ];
                  }];
              
                  icon = "${pkgs.nixos-icons}/share/icons/hicolor/scalable/apps/nix-snowflake.svg";
                  definedAliases = [ "@np" ];
                };
              
                "NixOS Wiki" = {
                  urls = [{ template = "https://nixos.wiki/index.php?search={searchTerms}"; }];
                  iconUpdateURL = "https://nixos.wiki/favicon.png";
                  updateInterval = 24 * 60 * 60 * 1000; # every day
                  definedAliases = [ "@nw" ];
                };
            };

            order = [ "DuckDuckGo" ];
          }
          bookmarks = [
          {
              name = "Kabtop Nextcloud";
              url = "https://cloud.kabtop.de/"
          }
          {
              name = "Home Assistant";
              url = "https://hass.home.opel-online.de/"
          }
          {
              name = "Netflix";
              url = "https://netflix.com/browse"
          }
          {
              name = "YouTube";
              url = "https://youtube.com/"
          }
          {
              name = "Kicker";
              url = "https://kicker.de/"
          }
          {
              name = "Chilloutzone";
              url = "https://chilloutzone.net/"
          }
          {
              name = "myDealZ";
              url = "https://mydealz.de/"
          }
          {
              name = "Kabtop Git";
              url = "https://git.kabtop.de/"
          }
          {
              name = "Spotify";
              url = "https://open.spotify.com/"
          }
          {
              name = "Tech":
              bookmarks = [
                {
                    name = "Golem";
                    url = "https://golem.de/"
                }
                {
                    name = "Heise";
                    url = "https://heise.de/"
                }
                {
                    name = "Phoronix";
                    url = "https://phoronix.com/"
                }
              ];
          }
          {
              name = "Foren":
              bookmarks = [
                {
                    name = "Archlinux-en";
                    url = "https://archlinux.org/"
                }
                {
                    name = "Archlinux-ARM";
                    url = "https://archlinuxarm.org/"
                }
                {
                    name = "Archlinux-de";
                    url = "https://archlinux.de/"
                }
              ];
          }
      };

      settings = {
      };

      extensions = [
          with pkgs.nur.repos.rycee.firefox-addons; [
            h264ity
            honey
            keepassxc-browser
            multi-account-containers
            netflix-1080p
            ublock-origin
            sidebery
          ]
      ]
    };
  };
}
